#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   gi-glib
version:                2.0.30
visibility:             public
id:                     gi-glib-2.0.30-GQdzVbXRko071pCrqOIWOd
key:                    gi-glib-2.0.30-GQdzVbXRko071pCrqOIWOd
license:                LGPL-2.1-only
maintainer:             Iñaki García Etxebarria
author:                 Iñaki García Etxebarria
homepage:               https://github.com/haskell-gi/haskell-gi
synopsis:               GLib bindings
description:            Bindings for GLib, autogenerated by haskell-gi.
category:               Bindings
abi:                    268d45bb5486cdc6a09fbfa7cefef00a
exposed:                True
exposed-modules:
    GI.GLib GI.GLib.Callbacks GI.GLib.Config GI.GLib.Constants
    GI.GLib.Enums GI.GLib.Flags GI.GLib.Functions GI.GLib.Structs
    GI.GLib.Structs.Allocator GI.GLib.Structs.AsyncQueue
    GI.GLib.Structs.BookmarkFile GI.GLib.Structs.ByteArray
    GI.GLib.Structs.Bytes GI.GLib.Structs.Cache
    GI.GLib.Structs.Checksum GI.GLib.Structs.Completion
    GI.GLib.Structs.Cond GI.GLib.Structs.Data GI.GLib.Structs.Date
    GI.GLib.Structs.DateTime GI.GLib.Structs.DebugKey
    GI.GLib.Structs.Dir GI.GLib.Structs.HashTableIter
    GI.GLib.Structs.Hmac GI.GLib.Structs.Hook GI.GLib.Structs.HookList
    GI.GLib.Structs.IOChannel GI.GLib.Structs.IOFuncs
    GI.GLib.Structs.KeyFile GI.GLib.Structs.LogField
    GI.GLib.Structs.MainContext GI.GLib.Structs.MainLoop
    GI.GLib.Structs.MappedFile GI.GLib.Structs.MarkupParseContext
    GI.GLib.Structs.MarkupParser GI.GLib.Structs.MatchInfo
    GI.GLib.Structs.MemChunk GI.GLib.Structs.MemVTable
    GI.GLib.Structs.Node GI.GLib.Structs.Once
    GI.GLib.Structs.OptionContext GI.GLib.Structs.OptionEntry
    GI.GLib.Structs.OptionGroup GI.GLib.Structs.PathBuf
    GI.GLib.Structs.PatternSpec GI.GLib.Structs.PollFD
    GI.GLib.Structs.PtrArray GI.GLib.Structs.Queue
    GI.GLib.Structs.RWLock GI.GLib.Structs.Rand
    GI.GLib.Structs.RecMutex GI.GLib.Structs.Regex
    GI.GLib.Structs.Relation GI.GLib.Structs.Scanner
    GI.GLib.Structs.ScannerConfig GI.GLib.Structs.Sequence
    GI.GLib.Structs.SequenceIter GI.GLib.Structs.Source
    GI.GLib.Structs.SourceCallbackFuncs GI.GLib.Structs.SourceFuncs
    GI.GLib.Structs.StatBuf GI.GLib.Structs.String
    GI.GLib.Structs.StringChunk GI.GLib.Structs.StrvBuilder
    GI.GLib.Structs.TestCase GI.GLib.Structs.TestConfig
    GI.GLib.Structs.TestLogBuffer GI.GLib.Structs.TestLogMsg
    GI.GLib.Structs.TestSuite GI.GLib.Structs.Thread
    GI.GLib.Structs.ThreadPool GI.GLib.Structs.TimeVal
    GI.GLib.Structs.TimeZone GI.GLib.Structs.Timer
    GI.GLib.Structs.TrashStack GI.GLib.Structs.Tree
    GI.GLib.Structs.TreeNode GI.GLib.Structs.Tuples
    GI.GLib.Structs.UnixPipe GI.GLib.Structs.Uri
    GI.GLib.Structs.UriParamsIter GI.GLib.Structs.VariantBuilder
    GI.GLib.Structs.VariantDict GI.GLib.Structs.VariantType
    GI.GLib.Unions GI.GLib.Unions.DoubleIEEE754
    GI.GLib.Unions.FloatIEEE754 GI.GLib.Unions.Mutex
    GI.GLib.Unions.TokenValue

import-dirs:            /usr/lib/ghc-9.6.6/site-local/gi-glib-2.0.30
library-dirs:
    /usr/lib/ghc-9.6.6/site-local/gi-glib-2.0.30 /usr/lib

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/gi-glib-2.0.30 /usr/lib

dynamic-library-dirs:   /usr/lib /usr/lib
data-dir:               /usr/share/haskell-gi-glib
hs-libraries:           HSgi-glib-2.0.30-GQdzVbXRko071pCrqOIWOd
extra-libraries:        glib-2.0
extra-libraries-static: glib-2.0 atomic m sysprof-capture-4 pcre2-8 pthread
include-dirs:
    /usr/include/glib-2.0 /usr/lib/glib-2.0/include
    /usr/include/sysprof-6 /usr/include

depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    haskell-gi-0.26.16-DT0fMT4725hIpjqfyuoqdQ
    haskell-gi-base-0.26.9-9dGlnSJnubc2h9MiqHeprA
    haskell-gi-overloading-1.0-6w3IXGDooXgu3RA2LfTuf text-2.0.2
    transformers-0.6.1.0

haddock-interfaces:     /usr/share/doc/haskell-gi-glib/html/gi-glib.haddock
haddock-html:           /usr/share/doc/haskell-gi-glib/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

